==> huaweicloudsdkcsms-3.1.141-py2.py3-none-any.whl: huaweicloudsdkcsms/v1/model/delete_secret_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSecretTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'secret_id': 'str',
        'key': 'str'
    }

    attribute_map = {
        'secret_id': 'secret_id',
        'key': 'key'
    }

    def __init__(self, secret_id=None, key=None):
        """DeleteSecretTagRequest

        The model defined in huaweicloud sdk

        :param secret_id: 凭据ID
        :type secret_id: str
        :param key: 标签键的值
        :type key: str
        """
        
        

        self._secret_id = None
        self._key = None
        self.discriminator = None

        self.secret_id = secret_id
        self.key = key

    @property
    def secret_id(self):
        """Gets the secret_id of this DeleteSecretTagRequest.

        凭据ID

        :return: The secret_id of this DeleteSecretTagRequest.
        :rtype: str
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        """Sets the secret_id of this DeleteSecretTagRequest.

        凭据ID

        :param secret_id: The secret_id of this DeleteSecretTagRequest.
        :type secret_id: str
        """
        self._secret_id = secret_id

    @property
    def key(self):
        """Gets the key of this DeleteSecretTagRequest.

        标签键的值

        :return: The key of this DeleteSecretTagRequest.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this DeleteSecretTagRequest.

        标签键的值

        :param key: The key of this DeleteSecretTagRequest.
        :type key: str
        """
        self._key = key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSecretTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcsms-3.1.146-py2.py3-none-any.whl: huaweicloudsdkcsms/v1/model/delete_secret_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSecretTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'secret_id': 'str',
        'key': 'str'
    }

    attribute_map = {
        'secret_id': 'secret_id',
        'key': 'key'
    }

    def __init__(self, secret_id=None, key=None):
        r"""DeleteSecretTagRequest

        The model defined in huaweicloud sdk

        :param secret_id: 凭据ID
        :type secret_id: str
        :param key: 标签键的值
        :type key: str
        """
        
        

        self._secret_id = None
        self._key = None
        self.discriminator = None

        self.secret_id = secret_id
        self.key = key

    @property
    def secret_id(self):
        r"""Gets the secret_id of this DeleteSecretTagRequest.

        凭据ID

        :return: The secret_id of this DeleteSecretTagRequest.
        :rtype: str
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        r"""Sets the secret_id of this DeleteSecretTagRequest.

        凭据ID

        :param secret_id: The secret_id of this DeleteSecretTagRequest.
        :type secret_id: str
        """
        self._secret_id = secret_id

    @property
    def key(self):
        r"""Gets the key of this DeleteSecretTagRequest.

        标签键的值

        :return: The key of this DeleteSecretTagRequest.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        r"""Sets the key of this DeleteSecretTagRequest.

        标签键的值

        :param key: The key of this DeleteSecretTagRequest.
        :type key: str
        """
        self._key = key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSecretTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
